=================
WaniKani Notifier
=================


.. image:: https://img.shields.io/pypi/v/wanikani_notifier.svg
        :target: https://pypi.python.org/pypi/wanikani_notifier

.. image:: https://readthedocs.org/projects/wanikani-notifier/badge/?version=latest
        :target: https://wanikani-notifier.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Notifies a WaniKani user for new assignments to do.


* Free software: MIT license
* Documentation: https://wanikani-notifier.readthedocs.io.


Features
--------

* Can fetch

  * Assignments that became available in the last x hours
  * All available assignments

* Sends a notification via different notification systems whenever new reviews and/or lessons are available

  * List of supported notifiers:

    * Console
    * Pushover
    * PushSafer

  * Can send a title and message and optionally a URL and/or and icon


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
